| Title: | A 'shiny' Package for Data Analysis |
| Version: | 0.1.5 |
| Maintainer: | Luís Gustavo Schuck <luisgustavoschuck@yahoo.com.br> |
| Description: | Provides a 'shiny' application with a user-friendly interface for interactive data analysis. It supports exploratory data analysis through descriptive statistics, data visualization, statistical tests (e.g., normality assessment), linear modeling, data import, transformation and reporting. For more details see Shapiro and Wilk (1965) <doi:10.2307/2333709>. |
| License: | AGPL (≥ 3) |
| URL: | https://github.com/lgschuck/spada |
| BugReports: | https://github.com/lgschuck/spada/issues |
| Depends: | R (≥ 4.4.0) |
| Imports: | bsicons (≥ 0.1.2), bslib (≥ 0.10.0), collapse (≥ 2.1.6), data.table (≥ 1.18.2.1), DescTools (≥ 0.99.60), dplyr (≥ 1.1.4), ggplot2 (≥ 4.0.1), gt (≥ 1.3.0), haven (≥ 2.5.5), htmltools (≥ 0.5.9), mirai (≥ 2.5.3), qs2 (≥ 0.1.7), rlang (≥ 1.1.7), sass (≥ 0.4.10), shiny (≥ 1.12.1), shinyWidgets (≥ 0.9.0), waiter (≥ 0.2.5.1) |
| Encoding: | UTF-8 |
| RoxygenNote: | 7.3.3 |
| Suggests: | knitr, rmarkdown, testthat (≥ 3.0.0), tidyselect |
| VignetteBuilder: | knitr |
| Config/testthat/edition: | 3 |
| NeedsCompilation: | no |
| Packaged: | 2026-04-14 11:34:28 UTC; luisg |
| Author: | Luís Gustavo Schuck [aut, cre] |
| Repository: | CRAN |
| Date/Publication: | 2026-04-21 08:40:02 UTC |
Launch a 'shiny' application for data analysis
Description
Generates a 'shiny' application for interactive data analysis.
Usage
spada(..., run_local = TRUE)
Arguments
... |
Objects of data.frame class |
run_local |
Logical. Whether to run the application locally. |
Value
An object of class 'shiny.appobj' representing the 'shiny' application. Printing the object launches the interactive app in a web browser.
Examples
if(interactive()) spada(datasets::mtcars)