| Title: | A 'shiny' Package for Data Analysis |
|---|---|
| Description: | Provides a 'shiny' application with a user-friendly interface for interactive data analysis. It supports exploratory data analysis through descriptive statistics, data visualization, statistical tests (e.g., normality assessment), linear modeling, data import, transformation and reporting. For more details see Shapiro and Wilk (1965) <doi:10.2307/2333709>. |
| Authors: | Luís Gustavo Schuck [aut, cre] |
| Maintainer: | Luís Gustavo Schuck <[email protected]> |
| License: | AGPL (>= 3) |
| Version: | 0.1.6.9000 |
| Built: | 2026-06-03 08:34:50 UTC |
| Source: | https://github.com/lgschuck/spada |
Generates a 'shiny' application for interactive data analysis.
spada(..., run_local = TRUE)spada(..., run_local = TRUE)
... |
Objects of data.frame class |
run_local |
Logical. Whether to run the application locally. If TRUE the app will close at session end. |
An object of class 'shiny.appobj' representing the 'shiny' application. Printing the object launches the interactive app in a web browser.
if(interactive()) spada(datasets::mtcars)if(interactive()) spada(datasets::mtcars)